<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <!-- Developed by Peter Weaver, Weaver Consulting Services Inc., 2019  -->
  <!-- V2.0 March/2021 - Added more details in comments column -->
  <!-- V3.0 May/2022 - Added Fibre Disks -->
  <!-- V4.0 June/2022 - Added vtVAX -->
  <!-- V4.1 September/2022 - Changed text for password on OPA0 -->
  <!-- V4.2 July/2023 - Added section for KFDDA disks -->

  <xsl:output method="html" encoding="UTF-8" />

  <xsl:template match="/">

    <xsl:for-each select="emulator_config | vtvax">

      <html>
        <head>
          <xsl:choose>
            <xsl:when test="name()='emulator_config'">
              <xsl:variable name="hardware" select='"Alpha"' />
              <h1>Alpha Configuration</h1>
            </xsl:when>
            <xsl:otherwise>
              <xsl:variable name="hardware" select='"VAX"' />
              <h1>VAX Configuration</h1>
            </xsl:otherwise>
          </xsl:choose>
        </head>

        <body>

          <p>
            This configuration is using <xsl:value-of select="name()"/> Version  <xsl:value-of select="@version"/>.
          </p>

            <p>
              <xsl:value-of select="comment" disable-output-escaping="no"/>
            </p>

          <!--  **************** Environment ************ -->

          <xsl:for-each select="environment">
            <h3>Environment</h3>

            <table border="1" style="margin-left:25px">
              <tr bgcolor="#187e37">
                <th style="text-align:left">Item</th>
                <th style="text-align:left">Value</th>
                <th style="text-align:left">Comments</th>
              </tr>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>Configuration Name</td>
                  <td><xsl:value-of select="name" disable-output-escaping="yes"/></td>
                  <td></td>
                </tr>
              </xsl:if>

              <tr>
                <td>Log File</td>
                <td>

                  <xsl:choose>
                    <xsl:when test="logging = ''">
                      logfile.log
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:value-of select="logging"/>
                    </xsl:otherwise>
                  </xsl:choose>
                </td>
                <td></td>
              </tr>

              <xsl:if test="name(/*)='vtvax'">
                <tr>
                  <td>License Group</td>
                  <td><xsl:value-of select="licensegroup" disable-output-escaping="yes"/></td>
                  <td></td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='vtvax'">
                <tr>
                  <td>License Temp</td>
                  <td><xsl:value-of select="licensetemp" disable-output-escaping="yes"/></td>
                  <td></td>
                </tr>
              </xsl:if>


              <xsl:if test="name(/*)='vtvax'">
                <tr>
                  <td>Emulation CPU</td>
                  <td><xsl:value-of select="emulationcpu" disable-output-escaping="yes"/></td>
                  <td></td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='vtvax'">
                <tr>
                  <td>Emulation I/O CPU</td>
                  <td><xsl:value-of select="emulationiocpu" disable-output-escaping="yes"/></td>
                  <td></td>
                </tr>
              </xsl:if>


            </table>

          </xsl:for-each> <!-- environment -->

          <xsl:for-each select="cpu">
            <h3>CPU</h3>

            <table border="1" style="margin-left:25px">
              <tr bgcolor="#187e37">
                <th style="text-align:left">Item</th>
                <th style="text-align:left">Value</th>
                <th style="text-align:left">Comments</th>
              </tr>
              <tr>
                <td>Model</td>
                <td><xsl:value-of select="model"/></td>
                <td></td>
              </tr>
              <tr>
                <td>Memory</td>
                <td><xsl:value-of select="memory"/></td>
                <td></td>
              </tr>
              <tr>
                <td>NVRAM File</td>
                <td>
                  <!--  <xsl:value-of select="nvram"/> -->
                  <xsl:choose>
                    <xsl:when test="nvram = ''">
                      nvram.dat
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:value-of select="nvram"/>
                    </xsl:otherwise>
                  </xsl:choose>
                </td>
                <td>This file is used to store boot options of the VAX.</td>
              </tr>
              <tr>
                <td>CPU Idle</td>
                <td><xsl:value-of select="cpuidle"/></td>
                <td>If the VAX is idle for most of the time enable this to save on host resources. If the VAX is very busy then enabling this can reduce performance.</td>
              </tr>
              <tr>
                <td>Instruction Caching</td>
                <td><xsl:value-of select="instructioncaching"/></td>
                <td>Normally you should enable this unless instructed to disable it by your support.</td>
              </tr>
              <tr>
                <td>Instruction Delay</td>
                <td><xsl:value-of select="instructiondelay"/></td>
                <td>Normally leave this as 0 unless instructed to change it by your support.</td>
              </tr>
              <tr>
                <td>Instruction Delay Timeout</td>
                <td><xsl:value-of select="instructiondelaytmo"/></td>
                <td>Normally leave this as 0 unless instructed to change it by your support.</td>
              </tr>

            </table>
          </xsl:for-each> <!-- cpu -->

          <!-- ********************** Machine Definition ***************** -->
          <!-- This selects either es40 or eb164 for Alpha, VAX do not have es40 or eb164 so this section is skipped -->
          <xsl:for-each select="es40 | eb164">
            <h3>Machine Definition</h3>

            <!-- This will only exist on Alpha, the VAX config will not find this -->
            <xsl:for-each select="dsrdb">
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>
                  <td>Machine Type</td>
                  <td><xsl:value-of select="identification"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>System Marketing Model</td>
                  <td><xsl:value-of select="smm"/></td>
                  <td>usually blank</td>
                </tr>
                <tr>
                  <td>Custom hardware name</td>
                  <td><xsl:value-of select="hardware_name"/></td>
                  <td>usually blank</td>
                </tr>
              </table>
            </xsl:for-each> <!-- dsrdb -->



            <!-- *************************** CPU Details *************************** -->
            <h3>CPU Details</h3>

            <table border="1" style="margin-left:25px">
              <tr bgcolor="#187e37">
                <th style="text-align:left">Item</th>
                <th style="text-align:left">Value</th>
                <th style="text-align:left">Comments</th>
              </tr>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>CPU Acceleration</td>
                  <td>
                    <!-- <xsl:value-of select="jit"/> -->
                    <xsl:choose>
                      <xsl:when test="jit=1">
                        ON
                      </xsl:when>
                      <xsl:otherwise>
                        OFF
                      </xsl:otherwise>
                    </xsl:choose>
                  </td>
                  <td>This has no effect on vtAlpha-AS, should be left ON for all other machines unless changed by vtAlpha support.</td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>JIT Processors</td>
                  <td><xsl:value-of select="jit_processors"/></td>
                  <td>Only used under guidance of you vtAlpha support organization.</td>
                </tr>
              </xsl:if>


              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>NVRAM File</td>
                  <td>
                    <!--  <xsl:value-of select="nvram"/> -->
                    <xsl:choose>
                      <xsl:when test="nvram = ''">
                        nvram.dat
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:value-of select="nvram"/>
                      </xsl:otherwise>
                    </xsl:choose>
                  </td>
                  <td>This file is used to store boot options of the Alpha, such as auto_action etc.</td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>Number of CPUs</td>
                  <td><xsl:value-of select="cpus"/></td>
                  <td></td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>CPU Major Type</td>
                  <td><xsl:value-of select="cpu_majortype"/></td>
                  <td>Leave blank unless directed by vtAlpha support</td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>CPU Minor Type</td>
                  <td><xsl:value-of select="cpu_minortype"/></td>
                  <td>Leave blank unless directed by vtAlpha support</td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>CPU Variant</td>
                  <td><xsl:value-of select="cpu_variant"/></td>
                  <td>Leave blank unless directed by vtAlpha support</td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>CPU Revision</td>
                  <td><xsl:value-of select="cpu_revision"/></td>
                  <td>Leave blank unless directed by vtAlpha support</td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>CPU Serial Number</td>
                  <td><xsl:value-of select="cpu_serialnumbers"/></td>
                  <td>Define only if needed</td>
                </tr>
              </xsl:if>

              <xsl:if test="name(/*)='emulator_config'">
                <tr>
                  <td>Trace Level</td>
                  <td><xsl:value-of select="trace_level"/></td>
                  <td>Leave as 0 unless directed by vtAlpha support</td>
                </tr>
              </xsl:if>

            </table>


            <!-- ********************* Memory *************************** -->
            <xsl:for-each select="memory">

              <h3>Memory</h3>
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>
                  <td>Memory Size</td>
                  <td><xsl:value-of select="size"/></td>
                  <td>in MB</td>
                </tr>
              </table>

            </xsl:for-each> <!-- memmory -->


            <!-- ********************** Built-in Terminals ************* -->
            <h3>Built-in Terminals</h3>


            <xsl:for-each select="isa">
              <xsl:for-each select="opa0 | com2">
                <table border="1" style="margin-left:25px">
                  <tr bgcolor="#187e37">
                    <th style="text-align:left">Item</th>
                    <th style="text-align:left">Value</th>
                    <th style="text-align:left">Comments</th>
                  </tr>
                  <tr>
                    <td><b>Terminal</b></td>
                    <!--  This will return either opa0 or com2 -->
                    <td><b><xsl:value-of select="name()"/></b></td>
                    <td></td>
                  </tr>
                  <tr>
                    <td>Port/Device</td>
                    <td><xsl:value-of select="device"/></td>
                    <td>Telnet or SSH port or Physical Device</td>
                  </tr>
                  <tr>
                    <td>Log File</td>
                    <td><xsl:value-of select="logfile"/></td>
                    <td>Logging can slow down performance</td>
                  </tr>
                  <tr>
                    <td>Password</td>
                    <td>
                      <!-- Password: <xsl:value-of select="password"/> -->
                      <xsl:choose>
                        <xsl:when test="password = ''">
                          none
                        </xsl:when>
                        <xsl:otherwise>
                          *hidden*
                        </xsl:otherwise>
                      </xsl:choose>
                    </td>
                    <td>If OPA0 uses telnet or a physical port then you should either firewall it or password protect it, ssh will automatically password protect it</td>
                  </tr>
                  <tr>
                    <td>Baud Rate</td>
                    <td><xsl:value-of select="baudrate"/></td>
                    <td>Only for Physical Devices</td>
                  </tr>
                  <tr>
                    <td>Time Stamps</td>
                    <td><xsl:value-of select="timestamps"/></td>
                    <td>If there is a log file this will time stamp each logged entry</td>
                  </tr>
                  <tr>
                    <td>Line Trace Level</td>
                    <td><xsl:value-of select="trace_level"/></td>
                    <td>Should only be used when troubleshooting</td>
                  </tr>
                  <tr>
                    <td>Options</td>
                    <td><xsl:value-of select="options"/></td>
                    <td>This can be raw or nodelay or blank</td>
                  </tr>


                </table>
              </xsl:for-each> <!-- opa0 | com2 -->
            </xsl:for-each>   <!-- isa -->

            <h4>Device Naming Rules</h4>
            <p>
              For vtAlpha-AS and -BS models, adapters are configured in the following order: Slot 2, 0, 1, 3, 4, 5,
              6, 7, 8, 9, 10, 11, 12, 13, 14. The first non-empy slot from that list becomes A, the second non-empty slot from that list
              becomes B. For example, SCSI adapters configured in slots 0, 1 and 2 will be
              designated PKB, PKC, and PKA, respectively. If the adapters are configured in slots 1, 3, and 5,
              they will be designated PKA, PKB, and PKC, respectively.
            </p>
            <p>
              For vtAlpha-CS models, the configuration sequence is slot 0, 1, 6, 7, 8
            </p>
            <p>
              For vtAlpha-DS and -ES models, the sequence is bus 1, slot 0 - 5, then bus 0 slot 0 - 3.
            </p>

            <xsl:for-each select="pci">
              <h3>PCI Bus # <xsl:value-of select="bus_num"/></h3>
              <xsl:for-each select="item">

                <!--       <h4>Slot #<xsl:value-of select="slot"/></h4>  -->

                <xsl:for-each select="degxa | de500 | ei1000 | de600 | de450 | de435">

                  <table border="1" style="margin-left:25px">
                    <tr bgcolor="#187e37">
                      <th style="text-align:left">Item</th>
                      <th style="text-align:left">Value</th>
                      <th style="text-align:left">Comments</th>
                    </tr>

                    <tr>
                      <td>Ethernet Device</td>
                      <!-- using name() will return either degxa or de500 or whatever the name is-->
                      <td><xsl:value-of select="name()"/></td>
                      <td></td>
                    </tr>
                    <tr>
                      <td>Bus</td>
                      <td><xsl:value-of select="../../bus_num"/> </td>
                      <td>For vtAlpha-DS and vtAlpha-ES we configure bus 1 then bus 0, all others have only 1 bus</td>
                    </tr>
                    <tr>
                      <td>Slot</td>
                      <td><xsl:value-of select="../slot"/></td>
                      <td>See Device Naming Rules to see the order slots are configured</td>
                    </tr>
                    <tr>
                      <td>Trace Level</td>
                      <td><xsl:value-of select="trace_level"/></td>
                      <td>Leave as 0 unless directed by vtAlpha support</td>
                    </tr>
                    <xsl:for-each select="device">
                      <tr>
                        <td>Interface</td>
                        <td><xsl:value-of select="interface"/></td>
                        <td>This is the physical port on the host</td>
                      </tr>
                      <tr>
                        <td>MAC</td>
                        <td><xsl:value-of select="mac"/></td>
                        <td>Normally blank unless licensing requires it</td>
                      </tr>
                      <tr>
                        <td>Trace Level</td>
                        <td><xsl:value-of select="trace_level"/></td>
                        <td>Leave as 0 unless directed by vtAlpha support</td>
                      </tr>

                    </xsl:for-each> <!-- device -->

                  </table>

                </xsl:for-each> <!-- degxa | de500 | ei1000 | de600 | de450 | de435 -->


                <xsl:for-each select="isp1040 | kgpsa">

                  <xsl:for-each select="scsi_bus">

                    <xsl:for-each select="scsi_device">

                      <xsl:for-each select="container_disk">
                        <table border="1" style="margin-left:25px">
                          <tr bgcolor="#187e37">
                            <th style="text-align:left">Item</th>
                            <th style="text-align:left">Value</th>
                            <th style="text-align:left">Comments</th>
                          </tr>

                          <tr>
                            <td><b>Type</b></td>
                            <xsl:choose>
                              <xsl:when test="../../../target">
                                <td><b>SCSI Virtual Disk</b></td>
                              </xsl:when>
                              <xsl:otherwise>
                                <td><b>Fibre Virtual Disk</b></td>
                              </xsl:otherwise>
                            </xsl:choose>

                            <td></td>
                          </tr>
                          <tr>
                            <td>Bus</td>
                            <td><xsl:value-of select="../../../../../bus_num"/> </td>
                            <td>For vtAlpha-DS and vtAlpha-ES we configure bus 1 then bus 0, all others have only 1 bus</td>
                          </tr>
                          <tr>
                            <td>Slot</td>
                            <td><xsl:value-of select="../../../../slot"/></td>
                            <td>See Device Naming Rules to see the order slots are configured</td>
                          </tr>
                          <xsl:choose>
                            <xsl:when test="../../../target">
                              <tr>
                                <td>Bus Target</td>
                                <td><xsl:value-of select="../../../target"/> </td>
                                <td></td>
                              </tr>
                            </xsl:when>
                            <xsl:otherwise>
                              <tr>
                                <td>Hostname</td>
                                <td><xsl:value-of select="../../../hostname"/> </td>
                                <td></td>
                              </tr>
                              <tr>
                                <td>Nodename</td>
                                <td><xsl:value-of select="../../../nodename"/> </td>
                                <td></td>
                              </tr>
                              <tr>
                                <td>Porttname</td>
                                <td><xsl:value-of select="../../../portname"/> </td>
                                <td></td>
                              </tr>
                              <tr>
                                <td>Lunmap</td>
                                <td><xsl:value-of select="../../../lunmap"/> </td>
                                <td></td>
                              </tr>
                              <tr>
                                <td>Options</td>
                                <td><xsl:value-of select="../../../options"/> </td>
                                <td></td>
                              </tr>
                            </xsl:otherwise>
                          </xsl:choose>
                          <tr>
                            <td>LUN</td>
                            <td><xsl:value-of select="../../../lun"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Trace Level</td>
                            <td><xsl:value-of select="../../../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>
                          <xsl:if test="../bus_num">
                            <tr>
                              <td>SCSI Bus Number</td>
                              <td><xsl:value-of select="../bus_num"/> </td>
                              <td></td>
                            </tr>
                          </xsl:if>
                          <xsl:if test="../target">
                            <tr>
                              <td>SCSI Target</td>
                              <td><xsl:value-of select="../target"/> </td>
                              <td></td>
                            </tr>
                          </xsl:if>
                          <tr>
                            <td>LUN</td>
                            <td><xsl:value-of select="../lun"/> </td>
                            <td>The LUN can be used to modify the device name, see the reference manual for details</td>
                          </tr>
                          <tr>
                            <td>Bus Trace Level</td>
                            <td><xsl:value-of select="../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>

                          <tr>
                            <td>Device</td>
                            <td><xsl:value-of select="device" disable-output-escaping="yes"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Read Only</td>
                            <td><xsl:value-of select="read_only"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Removeable</td>
                            <td><xsl:value-of select="removable"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Shared</td>
                            <td><xsl:value-of select="shared"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Read Cache</td>
                            <td><xsl:value-of select="read_cache"/></td>
                            <td>Can improve IO performance, but do not use when shared</td>
                          </tr>
                          <tr>
                            <td>Write Cache</td>
                            <td><xsl:value-of select="write_cache"/></td>
                            <td>Can improve IO performance, but do not use when shared</td>
                          </tr>
                          <tr>
                            <td>Extended Mode</td>
                            <td><xsl:value-of select="extended_mode"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>LBN</td>
                            <td><xsl:value-of select="num_lbn"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Sectors</td>
                            <td><xsl:value-of select="sectors"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Tracks</td>
                            <td><xsl:value-of select="tracks"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Cylinders</td>
                            <td><xsl:value-of select="cylinders"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Vendor</td>
                            <td><xsl:value-of select="vendor"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Product</td>
                            <td><xsl:value-of select="product"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Revision</td>
                            <td><xsl:value-of select="revision"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Serial</td>
                            <td><xsl:value-of select="serial"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>WWID</td>
                            <td><xsl:value-of select="wwid"/></td>
                            <td></td>
                          </tr>

                        </table>
                      </xsl:for-each> <!-- container_disk -->

                      <xsl:for-each select="physical_disk">

                        <table border="1" style="margin-left:25px">
                          <tr bgcolor="#187e37">
                            <th style="text-align:left">Item</th>
                            <th style="text-align:left">Value</th>
                            <th style="text-align:left">Comments</th>
                          </tr>


                          <tr>
                            <td><b>Type</b></td>
                            <td><b>Physical Disk</b></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Bus</td>
                            <td><xsl:value-of select="../../../../../bus_num"/> </td>
                            <td>For vtAlpha-DS and vtAlpha-ES we configure bus 1 then bus 0, all others have only 1 bus</td>
                          </tr>
                          <tr>
                            <td>Slot</td>
                            <td><xsl:value-of select="../../../../slot"/></td>
                            <td>See Device Naming Rules to see the order slots are configured</td>
                          </tr>
                          <tr>
                            <td>Bus Target</td>
                            <td><xsl:value-of select="../../../target"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>LUN</td>
                            <td><xsl:value-of select="../../../lun"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Trace Level</td>
                            <td><xsl:value-of select="../../../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>
                          <tr>
                            <td>SCSI Bus Number</td>
                            <td><xsl:value-of select="../bus_num"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>SCSI Target</td>
                            <td><xsl:value-of select="../target"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>SCSI LUN</td>
                            <td><xsl:value-of select="../lun"/> </td>
                            <td>The SCSI LUN can be used to modify the device name, see the reference manual for details</td>
                          </tr>
                          <tr>
                            <td>SCSI Bus Trace Level</td>
                            <td><xsl:value-of select="../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>

                          <tr>
                            <td>SCSI Device</td>
                            <td><xsl:value-of select="device" disable-output-escaping="yes"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Read Only</td>
                            <td><xsl:value-of select="read_only"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Removeable</td>
                            <td><xsl:value-of select="removable"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Shared</td>
                            <td><xsl:value-of select="shared"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Read Cache</td>
                            <td><xsl:value-of select="read_cache"/></td>
                            <td>Can improve IO performance, but do not use when shared</td>
                          </tr>
                          <tr>
                            <td>Write Cache</td>
                            <td><xsl:value-of select="write_cache"/></td>
                            <td>Can improve IO performance, but do not use when shared</td>
                          </tr>
                        </table>

                      </xsl:for-each> <!-- physical_disk -->

                      <xsl:for-each select="container_tape">

                        <table border="1" style="margin-left:25px">
                          <tr bgcolor="#187e37">
                            <th style="text-align:left">Item</th>
                            <th style="text-align:left">Value</th>
                            <th style="text-align:left">Comments</th>
                          </tr>

                          <tr>
                            <td><b>Type</b></td>
                            <td><b>Virtual Tape</b></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Bus</td>
                            <td><xsl:value-of select="../../../../../bus_num"/> </td>
                            <td>For vtAlpha-DS and vtAlpha-ES we configure bus 1 then bus 0, all others have only 1 bus</td>
                          </tr>
                          <tr>
                            <td>Slot</td>
                            <td><xsl:value-of select="../../../../slot"/></td>
                            <td>See Device Naming Rules to see the order slots are configured</td>
                          </tr>
                          <tr>
                            <td>Bus Target</td>
                            <td><xsl:value-of select="../../../target"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>LUN</td>
                            <td><xsl:value-of select="../../../lun"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Trace Level</td>
                            <td><xsl:value-of select="../../../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>
                          <tr>
                            <td>SCSI Bus Number</td>
                            <td><xsl:value-of select="../bus_num"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>SCSI Target</td>
                            <td><xsl:value-of select="../target"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>SCSI LUN</td>
                            <td><xsl:value-of select="../lun"/> </td>
                            <td>The SCSI LUN can be used to modify the device name, see the reference manual for details</td>
                          </tr>
                          <tr>
                            <td>SCSI Bus Trace Level</td>
                            <td><xsl:value-of select="../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>

                          <tr>
                            <td>SCSI Device</td>
                            <td><xsl:value-of select="device" disable-output-escaping="yes"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Read Only</td>
                            <td><xsl:value-of select="read_only"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Autoload</td>
                            <td><xsl:value-of select="autoload"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Compression</td>
                            <td><xsl:value-of select="compression"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Format</td>
                            <!-- <td><xsl:value-of select="format"/></td> -->
                            <td>
                              <xsl:choose>
                                <xsl:when test="format=0">
                                  Default
                                </xsl:when>
                                <xsl:when test="format=1">
                                  MTD
                                </xsl:when>
                                <xsl:when test="format=2">
                                  SMA
                                </xsl:when>
                                <xsl:when test="format=3">
                                  LM
                                </xsl:when>
                              </xsl:choose>
                            </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Maximum Size</td>
                            <td><xsl:value-of select="maxsize"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Vendor</td>
                            <td><xsl:value-of select="vendor"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Product</td>
                            <td><xsl:value-of select="product"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Revision</td>
                            <td><xsl:value-of select="revision"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Serial</td>
                            <td><xsl:value-of select="serial"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>WWID</td>
                            <td><xsl:value-of select="wwid"/></td>
                            <td></td>
                          </tr>

                        </table>

                      </xsl:for-each> <!-- container_disk -->




                    </xsl:for-each> <!-- scsi_device -->
                  </xsl:for-each> <!-- scsi_bus -->
                </xsl:for-each> <!-- isp1040 -->




                <xsl:for-each select="vtdsk">

                  <!--       <h5>SCSI Target: <xsl:value-of select="target"/> Lun: <xsl:value-of select="lun"/></h5> -->

                  <xsl:for-each select="scsi_bus">
                    <!--       <h5>SCSI Bus: <xsl:value-of select="bus_num"/></h5> -->



                    <xsl:for-each select="scsi_device">

                      <!--       <h5>SCSI Target: <xsl:value-of select="target"/> Lun: <xsl:value-of select="lun"/></h5> -->

                      <table border="1" style="margin-left:25px">
                        <tr bgcolor="#187e37">
                          <th style="text-align:left">Item</th>
                          <th style="text-align:left">Value</th>
                          <th style="text-align:left">Comments</th>
                        </tr>


                        <xsl:for-each select="container_disk">

                          <tr>
                            <td><b>Type</b></td>
                            <td><b>VTDSK Virtual Disk</b></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Bus</td>
                            <td><xsl:value-of select="../../../../../bus_num"/> </td>
                            <td>For vtAlpha-DS and vtAlpha-ES we configure bus 1 then bus 0, all others have only 1 bus</td>
                          </tr>
                          <tr>
                            <td>Slot</td>
                            <td><xsl:value-of select="../../../../slot"/></td>
                            <td>See Device Naming Rules to see the order slots are configured</td>
                          </tr>
                          <tr>
                            <td>Bus Target</td>
                            <td><xsl:value-of select="../../../target"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>LUN</td>
                            <td><xsl:value-of select="../../../lun"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Trace Level</td>
                            <td><xsl:value-of select="../../../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>
                          <tr>
                            <td>SCSI Bus Number</td>
                            <td><xsl:value-of select="../bus_num"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>SCSI Target</td>
                            <td><xsl:value-of select="../target"/> </td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>SCSI LUN</td>
                            <td><xsl:value-of select="../lun"/> </td>
                            <td>The SCSI LUN can be used to modify the device name, see the reference manual for details</td>
                          </tr>
                          <tr>
                            <td>SCSI Bus Trace Level</td>
                            <td><xsl:value-of select="../trace_level"/> </td>
                            <td>Leave as 0 unless directed by vtAlpha support</td>
                          </tr>
                          <tr>
                            <td>Device</td>
                            <td><xsl:value-of select="device" disable-output-escaping="yes"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Read Only</td>
                            <td><xsl:value-of select="read_only"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Removeable</td>
                            <td><xsl:value-of select="removable"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Shared</td>
                            <td><xsl:value-of select="shared"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Read Cache</td>
                            <td><xsl:value-of select="read_cache"/></td>
                            <td>Can improve IO performance, but do not use when shared</td>
                          </tr>
                          <tr>
                            <td>Write Cache</td>
                            <td><xsl:value-of select="write_cache"/></td>
                            <td>Can improve IO performance, but do not use when shared</td>
                          </tr>
                          <tr>
                            <td>Extended Mode</td>
                            <td><xsl:value-of select="extended_mode"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>LBN</td>
                            <td><xsl:value-of select="num_lbn"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Sectors</td>
                            <td><xsl:value-of select="sectors"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Tracks</td>
                            <td><xsl:value-of select="tracks"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Cylinders</td>
                            <td><xsl:value-of select="cylinders"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Vendor</td>
                            <td><xsl:value-of select="vendor"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Product</td>
                            <td><xsl:value-of select="product"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Revision</td>
                            <td><xsl:value-of select="revision"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>Serial</td>
                            <td><xsl:value-of select="serial"/></td>
                            <td></td>
                          </tr>
                          <tr>
                            <td>WWID</td>
                            <td><xsl:value-of select="wwid"/></td>
                            <td></td>
                          </tr>
                        </xsl:for-each> <!-- container_disk -->
                      </table>

                    </xsl:for-each> <!-- scsi_device -->
                  </xsl:for-each> <!-- scsi_bus -->
                </xsl:for-each> <!-- vtdsk -->

                <xsl:for-each select="pbxda">
                  <h3>Serial Line</h3>

                  <table border="1" style="margin-left:25px">
                    <tr bgcolor="#187e37">
                      <th style="text-align:left">Item</th>
                      <th style="text-align:left">Value</th>
                      <th style="text-align:left">Comments</th>
                    </tr>

                    <xsl:for-each select="item">
                      <tr>
                        <td><b>Line</b></td>
                        <td><b><xsl:value-of select="line"/></b></td>
                        <td></td>
                      </tr>
                      <tr>
                        <td>Port or Physical Device</td>
                        <td><xsl:value-of select="device"/></td>
                        <td></td>
                      </tr>
                      <tr>
                        <td>Options</td>
                        <td><xsl:value-of select="options"/></td>
                        <td>Valid options are raw or nodelay</td>
                      </tr>
                      <tr>
                        <td>Trace Level</td>
                        <td><xsl:value-of select="trace_level"/></td>
                        <td></td>
                      </tr>
                      <tr>
                        <td>Log File</td>
                        <td><xsl:value-of select="logfile"/></td>
                        <td></td>
                      </tr>
                      <tr>
                        <td>Time Stamp</td>
                        <td><xsl:value-of select="timestamp"/></td>
                        <td></td>
                      </tr>
                      <tr>
                        <td>Password</td>
                        <td>
                          <!-- Password: <xsl:value-of select="password"/> -->
                          <xsl:choose>
                            <xsl:when test="password = ''">
                              none
                            </xsl:when>
                            <xsl:otherwise>
                              *hidden*
                            </xsl:otherwise>
                          </xsl:choose>
                        </td>
                        <td></td>
                      </tr>

                    </xsl:for-each> <!-- item -->
                  </table>
                </xsl:for-each> <!-- pbxda -->

              </xsl:for-each> <!-- item  -->

            </xsl:for-each>  <!-- pci  -->

          </xsl:for-each>  <!-- es40 | eb164  -->

                      <xsl:for-each select="avt">
                      <h3>Terminals</h3>
              <xsl:for-each select="opa0 | com2">
                <table border="1" style="margin-left:25px">
                  <tr bgcolor="#187e37">
                    <th style="text-align:left">Item</th>
                    <th style="text-align:left">Value</th>
                    <th style="text-align:left">Comments</th>
                  </tr>
                  <tr>
                    <td><b>Terminal</b></td>
                    <!--  This will return either opa0 or com2 -->
                    <td><b><xsl:value-of select="name()"/></b></td>
                    <td></td>
                  </tr>
                  <tr>
                    <td>Port/Device</td>
                    <td><xsl:value-of select="device"/></td>
                    <td>Telnet or SSH port or Physical Device</td>
                  </tr>

                </table>
              </xsl:for-each> <!-- opa0  -->
            </xsl:for-each>   <!-- AVT -->


            <xsl:for-each select="console">
              <xsl:for-each select="device">
                <table border="1" style="margin-left:25px">
                  <tr bgcolor="#187e37">
                    <th style="text-align:left">Item</th>
                    <th style="text-align:left">Value</th>
                    <th style="text-align:left">Comments</th>
                  </tr>
                  <tr>
                    <td><b>Unit Number</b></td>
                    <td><b><xsl:value-of select="unitno"/></b></td>
                    <td></td>
                  </tr>
                  <tr>
                    <td>Port/Device</td>
                    <td><xsl:value-of select="path"/></td>
                    <td>Port for the console</td>
                  </tr>

                  <tr>
                    <td>Password</td>
                    <td>
                    <!-- Password: <xsl:value-of select="password"/> -->
                      <xsl:choose>
                        <xsl:when test="password = ''">
                          none
                        </xsl:when>
                         <xsl:otherwise>
                           *hidden*
                         </xsl:otherwise>
                      </xsl:choose>
                    </td>
                    <td>If OPA0 uses telnet or a physical port then you should either firewall it or password protect it, ssh will automatically password protect it</td>
                   </tr>

                  <tr>
                    <td>Break Key</td>
                    <td><xsl:value-of select="breakkey"/></td>
                    <td>Break Key to halt the system</td>
                  </tr>

                </table>
              </xsl:for-each> <!-- device  -->
            </xsl:for-each>   <!-- console -->




          <xsl:for-each select="quart">
            <h2>Terminals</h2>
            <h3>CID <xsl:value-of select="cid"/></h3>
            <table border="1" style="margin-left:25px">
              <tr bgcolor="#187e37">
                <th style="text-align:left">Item</th>
                <th style="text-align:left">Value</th>
                <th style="text-align:left">Comments</th>
              </tr>
              <xsl:for-each select="device">
                <tr>
                  <td><xsl:value-of select="unitno"/></td>
                  <!--  This will return either opa0 or com2 -->
                  <td><xsl:value-of select="path"/></td>
                  <td></td>
                </tr>
              </xsl:for-each> <!-- device -->
            </table>
          </xsl:for-each> <!-- quart -->

          <xsl:for-each select="kzdda">
            <h2>KZDDA Disks</h2>
            <h3>CID <xsl:value-of select="cid"/></h3>

            <xsl:for-each select="device">
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>
                  <td><b>Type</b></td>
                  <xsl:choose>
                    <xsl:when test="container_disk">
                      <td><b>Container Disk</b></td>
                    </xsl:when>
                    <xsl:otherwise>
                      <td><b>new disk??</b></td>
                    </xsl:otherwise>
                  </xsl:choose>

                  <td></td>
                </tr>
                <tr>
                  <td>Unit Number</td>
                  <td><xsl:value-of select="unitno"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Unit ID</td>
                  <td><xsl:value-of select="./container_disk/unitid"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Path</td>
                  <td><xsl:value-of select="./container_disk/path"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Media</td>
                  <td><xsl:value-of select="./container_disk/media"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Write Locked</td>
                  <td><xsl:value-of select="./container_disk/writelock"/></td>
                  <td></td>
                </tr>

              </table>

            </xsl:for-each> <!-- device -->

          </xsl:for-each> <!-- kzdda -->


          <xsl:for-each select="kfdda">
            <h2>KFDDA Disks</h2>
            <h3>CID <xsl:value-of select="cid"/></h3>

            <xsl:for-each select="node">


            <xsl:for-each select="device">
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>
                  <td><b>Type</b></td>
                  <xsl:choose>
                    <xsl:when test="container_disk">
                      <td><b>Container Disk</b></td>
                    </xsl:when>
                    <xsl:otherwise>
                      <td><b>new disk??</b></td>
                    </xsl:otherwise>
                  </xsl:choose>
                  <td></td>
                </tr>
                <tr>
                  <td>NodeID</td>
                  <td><xsl:value-of select="../nodeid"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Class</td>
                  <td><xsl:value-of select="../class"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Hostname</td>
                  <td><xsl:value-of select="../hostname"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Unit Number</td>
                  <td><xsl:value-of select="unitno"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Unit ID</td>
                  <td><xsl:value-of select="./container_disk/unitid"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Path</td>
                  <td><xsl:value-of select="./container_disk/path"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Media</td>
                  <td><xsl:value-of select="./container_disk/media"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Write Locked</td>
                  <td><xsl:value-of select="./container_disk/writelock"/></td>
                  <td></td>
                </tr>

              </table>

            </xsl:for-each> <!-- device -->
            </xsl:for-each> <!-- node -->

          </xsl:for-each> <!-- kfdda -->




          <xsl:for-each select="rqdx3">
            <h2>RQDX3 Disks</h2>
            <h3>CID <xsl:value-of select="cid"/></h3>

            <xsl:for-each select="device">
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>
                  <td><b>Type</b></td>
                  <xsl:choose>
                    <xsl:when test="container_disk">
                      <td><b>Container Disk</b></td>
                    </xsl:when>
                    <xsl:otherwise>
                      <td><b>new disk??</b></td>
                    </xsl:otherwise>
                  </xsl:choose>

                  <td></td>
                </tr>
                <tr>
                  <td>Unit Number</td>
                  <td><xsl:value-of select="unitno"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Unit ID</td>
                  <td><xsl:value-of select="./container_disk/unitid"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Path</td>
                  <td><xsl:value-of select="./container_disk/path"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Media</td>
                  <td><xsl:value-of select="./container_disk/media"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Write Locked</td>
                  <td><xsl:value-of select="./container_disk/writelock"/></td>
                  <td></td>
                </tr>

              </table>

            </xsl:for-each> <!-- device -->

          </xsl:for-each> <!-- rqdx3 -->


          <xsl:for-each select="sgec">
            <h2>Ethernet</h2>
            <h3>CID <xsl:value-of select="cid"/></h3>

            <xsl:for-each select="device">
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>
                  <td>Unit Number</td>
                  <td><xsl:value-of select="unitno"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>CSR</td>
                  <td><xsl:value-of select="csr"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Path</td>
                  <td><xsl:value-of select="path"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>MAC</td>
                  <td><xsl:value-of select="mac"/></td>
                  <td>Normally blank unless licensing requires it</td>
                </tr>
              </table>



            </xsl:for-each> <!-- device -->

          </xsl:for-each> <!-- sgec -->


          <xsl:for-each select="demna">
            <h2>Ethernet</h2>
            <h3>CID: <xsl:value-of select="cid"/>
              Hose: <xsl:value-of select="hose"/>
              Slot: <xsl:value-of select="slot"/>
            </h3>


            <xsl:for-each select="device">
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>
                  <td>Unit Number</td>
                  <td><xsl:value-of select="unitno"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Path</td>
                  <td><xsl:value-of select="path"/></td>
                  <td></td>
                </tr>
                <tr>
                  <td>MAC</td>
                  <td><xsl:value-of select="mac"/></td>
                  <td>Normally blank unless licensing requires it</td>
                </tr>
              </table>



            </xsl:for-each> <!-- device -->

          </xsl:for-each> <!-- demna -->

          <xsl:for-each select="dhv11">
            <h2>Additional Terminals</h2>

            <h3>CID: <xsl:value-of select="cid"/> CSR:
              <xsl:choose>
                <xsl:when test="csr = ''">
                  Not Specified
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="csr"/>
                </xsl:otherwise>
              </xsl:choose>

              Vector: <xsl:choose>
                <xsl:when test="vector = ''">
                  Not Specified
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="vector"/>
                </xsl:otherwise>
              </xsl:choose>
            </h3>


            <xsl:for-each select="device">
              <table border="1" style="margin-left:25px">
                <tr bgcolor="#187e37">
                  <th style="text-align:left">Item</th>
                  <th style="text-align:left">Value</th>
                  <th style="text-align:left">Comments</th>
                </tr>
                <tr>

                  <td><b>Unit Number</b></td>
                  <td><b><xsl:value-of select="unitno"/></b></td>
                  <td></td>
                </tr>
                <tr>
                  <td>Path</td>
                  <td><xsl:value-of select="path"/></td>
                  <td>This is either a port or a device</td>
                </tr>
                <tr>
                  <td>Log File</td>
                  <td><xsl:value-of select="logfile"/></td>
                  <td>Logging can slow down performance</td>
                </tr>
                <tr>
                  <td>Password</td>
                  <td>
                    <!-- Password: <xsl:value-of select="password"/> -->
                    <xsl:choose>
                      <xsl:when test="password = ''">
                        none
                      </xsl:when>
                      <xsl:otherwise>
                        *hidden*
                      </xsl:otherwise>
                    </xsl:choose>
                  </td>
                  <td></td>
                </tr>

              </table>
            </xsl:for-each>    <!-- device -->
          </xsl:for-each>   <!-- dhv11 -->


        </body>
      </html>

    </xsl:for-each> <!-- emulator_config -->

  </xsl:template>
</xsl:stylesheet>

